==> quasar-1.0.5.jar: META-INF/resources/webjars/quasar/1.0.5/icon-set/material-icons-round.js <==
export default {
  name: 'material-icons-round',
  type: {
    positive: 'r_check_circle',
    negative: 'r_warning',
    info: 'r_info',
    warning: 'r_priority_high'
  },
  arrow: {
    up: 'r_arrow_upward',
    right: 'r_arrow_forward',
    down: 'r_arrow_downward',
    left: 'r_arrow_back',
    dropdown: 'r_arrow_drop_down'
  },
  chevron: {
    left: 'r_chevron_left',
    right: 'r_chevron_right'
  },
  colorPicker: {
    spectrum: 'r_gradient',
    tune: 'r_tune',
    palette: 'r_style'
  },
  pullToRefresh: {
    icon: 'r_refresh'
  },
  carousel: {
    left: 'r_chevron_left',
    right: 'r_chevron_right',
    navigationIcon: 'r_lens',
    thumbnails: 'r_view_carousel'
  },
  chip: {
    remove: 'r_cancel',
    selected: 'r_check'
  },
  datetime: {
    arrowLeft: 'r_chevron_left',
    arrowRight: 'r_chevron_right',
    now: 'r_access_time',
    today: 'r_today'
  },
  editor: {
    bold: 'r_format_bold',
    italic: 'r_format_italic',
    strikethrough: 'r_strikethrough_s',
    underline: 'r_format_underlined',
    unorderedList: 'r_format_list_bulleted',
    orderedList: 'r_format_list_numbered',
    subscript: 'r_vertical_align_bottom',
    superscript: 'r_vertical_align_top',
    hyperlink: 'r_link',
    toggleFullscreen: 'r_fullscreen',
    quote: 'r_format_quote',
    left: 'r_format_align_left',
    center: 'r_format_align_center',
    right: 'r_format_align_right',
    justify: 'r_format_align_justify',
    print: 'r_print',
    outdent: 'r_format_indent_decrease',
    indent: 'r_format_indent_increase',
    removeFormat: 'r_format_clear',
    formatting: 'r_text_format',
    fontSize: 'r_format_size',
    align: 'r_format_align_left',
    hr: 'r_remove',
    undo: 'r_undo',
    redo: 'r_redo',
    header: 'r_format_size',
    code: 'r_code',
    size: 'r_format_size',
    font: 'r_font_download'
  },
  expansionItem: {
    icon: 'r_keyboard_arrow_down',
    denseIcon: 'r_arrow_drop_down'
  },
  fab: {
    icon: 'r_add',
    activeIcon: 'r_close'
  },
  field: {
    clear: 'r_cancel',
    error: 'r_error'
  },
  pagination: {
    first: 'r_first_page',
    prev: 'r_keyboard_arrow_left',
    next: 'r_keyboard_arrow_right',
    last: 'r_last_page'
  },
  rating: {
    icon: 'r_grade'
  },
  stepper: {
    done: 'r_check',
    active: 'r_edit',
    error: 'r_warning'
  },
  tabs: {
    left: 'r_chevron_left',
    right: 'r_chevron_right',
    up: 'r_keyboard_arrow_up',
    down: 'r_keyboard_arrow_down'
  },
  table: {
    arrowUp: 'r_arrow_upward',
    warning: 'r_warning',
    prevPage: 'r_chevron_left',
    nextPage: 'r_chevron_right'
  },
  tree: {
    icon: 'r_play_arrow'
  },
  uploader: {
    done: 'r_done',
    clear: 'r_clear',
    add: 'r_add_box',
    upload: 'r_cloud_upload',
    removeQueue: 'r_clear_all',
    removeUploaded: 'r_done_all'
  }
}

==> quasar-1.3.0.jar: META-INF/resources/webjars/quasar/1.3.0/icon-set/material-icons-round.js <==
export default {
  name: 'material-icons-round',
  type: {
    positive: 'r_check_circle',
    negative: 'r_warning',
    info: 'r_info',
    warning: 'r_priority_high'
  },
  arrow: {
    up: 'r_arrow_upward',
    right: 'r_arrow_forward',
    down: 'r_arrow_downward',
    left: 'r_arrow_back',
    dropdown: 'r_arrow_drop_down'
  },
  chevron: {
    left: 'r_chevron_left',
    right: 'r_chevron_right'
  },
  colorPicker: {
    spectrum: 'r_gradient',
    tune: 'r_tune',
    palette: 'r_style'
  },
  pullToRefresh: {
    icon: 'r_refresh'
  },
  carousel: {
    left: 'r_chevron_left',
    right: 'r_chevron_right',
    navigationIcon: 'r_lens',
    thumbnails: 'r_view_carousel'
  },
  chip: {
    remove: 'r_cancel',
    selected: 'r_check'
  },
  datetime: {
    arrowLeft: 'r_chevron_left',
    arrowRight: 'r_chevron_right',
    now: 'r_access_time',
    today: 'r_today'
  },
  editor: {
    bold: 'r_format_bold',
    italic: 'r_format_italic',
    strikethrough: 'r_strikethrough_s',
    underline: 'r_format_underlined',
    unorderedList: 'r_format_list_bulleted',
    orderedList: 'r_format_list_numbered',
    subscript: 'r_vertical_align_bottom',
    superscript: 'r_vertical_align_top',
    hyperlink: 'r_link',
    toggleFullscreen: 'r_fullscreen',
    quote: 'r_format_quote',
    left: 'r_format_align_left',
    center: 'r_format_align_center',
    right: 'r_format_align_right',
    justify: 'r_format_align_justify',
    print: 'r_print',
    outdent: 'r_format_indent_decrease',
    indent: 'r_format_indent_increase',
    removeFormat: 'r_format_clear',
    formatting: 'r_text_format',
    fontSize: 'r_format_size',
    align: 'r_format_align_left',
    hr: 'r_remove',
    undo: 'r_undo',
    redo: 'r_redo',
    header: 'r_format_size',
    code: 'r_code',
    size: 'r_format_size',
    font: 'r_font_download',
    viewSource: 'r_code'
  },
  expansionItem: {
    icon: 'r_keyboard_arrow_down',
    denseIcon: 'r_arrow_drop_down'
  },
  fab: {
    icon: 'r_add',
    activeIcon: 'r_close'
  },
  field: {
    clear: 'r_cancel',
    error: 'r_error'
  },
  pagination: {
    first: 'r_first_page',
    prev: 'r_keyboard_arrow_left',
    next: 'r_keyboard_arrow_right',
    last: 'r_last_page'
  },
  rating: {
    icon: 'r_grade'
  },
  stepper: {
    done: 'r_check',
    active: 'r_edit',
    error: 'r_warning'
  },
  tabs: {
    left: 'r_chevron_left',
    right: 'r_chevron_right',
    up: 'r_keyboard_arrow_up',
    down: 'r_keyboard_arrow_down'
  },
  table: {
    arrowUp: 'r_arrow_upward',
    warning: 'r_warning',
    prevPage: 'r_chevron_left',
    nextPage: 'r_chevron_right'
  },
  tree: {
    icon: 'r_play_arrow'
  },
  uploader: {
    done: 'r_done',
    clear: 'r_clear',
    add: 'r_add_box',
    upload: 'r_cloud_upload',
    removeQueue: 'r_clear_all',
    removeUploaded: 'r_done_all'
  }
}
